You've activated the Bader charge in-app guide. In this guide, you will learn how to use the app to compute the Bader charge of bulk LiCoO2.
Click on Step 1: Select structure and follow the instructions to proceed.
In the structure selection step, we select the LiCoO2 structure from the examples.
Once selected, we can view the structure in the viewer below.

#### Tasks

- Click on the "From examples" tab
- Select the LiCoO2 structure in the dropdown menu
- Click the Confirm button to proceed

Warning: Changes after confirmation will reset the following steps.
In the configuration step, we define the parameters needed to perform our calculation.

#### Tasks

1. Select Full geometry, i.e. we relaxed the structure optimizing both cell parameters and atom positions
2. Open step 2.1 for further instructions

Here we select the properties to calculate. Each property is associated with a workflow that will submit one or more calculations.

#### Tasks

1. Tick the Bader charge analysis checkbox
2. Open step 2.2 for further instructions

Here we can customize the calculation parameters. The settings are divided into several tabs:

- Basic settings: top-level calculation settings
- Advanced settings: fine-tune the calculations
- Plugin settings: parameters for plugin calculations, e.g. the Bader charge plugin

Note that the app pre-configures defaults for most parameters.

#### Tasks

1. Select Insulator electronic type
2. Select Fast protocol

In the submission step, we define the computational resources to be used in the calculations. The global resources are used to define resources across all workflow calculations. Optionally, you can override the resource settings for specific calculations.

Warning: If running locally (for example, on the AiiDAlab demo server), we recommend keeping nodes and CPUs at the default minimum of 1 each.

Once the resources are defined, we can optionally customize the workflow label (pre-filled according to the settings of steps 1 & 2), as well as provide a detailed description of the workflow. Once we are ready, we can submit the workflow.

#### Tasks

1. Select 1 node and 1 CPU for each of the codes below
2. (Optional) customize the workflow label
3. (Optional) add a workflow description
4. Click the Submit button to proceed

Warning: The workflow may take a moment to submit.
In the final step, we can monitor the calculation and view its results. A summary of calculation parameters is also provided. Raw input and output files may be downloaded upon workflow completion, as well as an AiiDA archive containing the full calculation provenance.

#### Tasks

1. If not already there, switch over to the Status panel
2. Monitor the calculation status. Once the calculation is complete, switch over to the Results panel for further instructions

Here in the results panel, each tab will open results pertaining to a specific calculation submitted by the workflow.
See further instructions below in the Bader charge tab.
When Bader charge results are available, the Load results button will become active allowing us to load the results from AiiDA.

#### Tasks

1. Once the calculation is complete, click on the Load results button to load the available results
2. Click the row in the result table to highlight the specific atom for which the Bader charge is being calculated.